==> zio-aws-devicefarm_3-5.17.112.1-sources.jar: zio/aws/devicefarm/model/PurchaseOfferingResponse.scala <==
package zio.aws.devicefarm.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class PurchaseOfferingResponse(
    offeringTransaction: Option[zio.aws.devicefarm.model.OfferingTransaction] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devicefarm.model.PurchaseOfferingResponse = {
    import PurchaseOfferingResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devicefarm.model.PurchaseOfferingResponse
      .builder()
      .optionallyWith(offeringTransaction.map(value => value.buildAwsValue()))(
        _.offeringTransaction
      )
      .build()
  }
  def asReadOnly: zio.aws.devicefarm.model.PurchaseOfferingResponse.ReadOnly =
    zio.aws.devicefarm.model.PurchaseOfferingResponse.wrap(buildAwsValue())
}
object PurchaseOfferingResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devicefarm.model.PurchaseOfferingResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devicefarm.model.PurchaseOfferingResponse =
      zio.aws.devicefarm.model.PurchaseOfferingResponse(
        offeringTransaction.map(value => value.asEditable)
      )
    def offeringTransaction
        : Option[zio.aws.devicefarm.model.OfferingTransaction.ReadOnly]
    def getOfferingTransaction: ZIO[
      Any,
      AwsError,
      zio.aws.devicefarm.model.OfferingTransaction.ReadOnly
    ] = AwsError.unwrapOptionField("offeringTransaction", offeringTransaction)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devicefarm.model.PurchaseOfferingResponse
  ) extends zio.aws.devicefarm.model.PurchaseOfferingResponse.ReadOnly {
    override val offeringTransaction
        : Option[zio.aws.devicefarm.model.OfferingTransaction.ReadOnly] = scala
      .Option(impl.offeringTransaction())
      .map(value => zio.aws.devicefarm.model.OfferingTransaction.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devicefarm.model.PurchaseOfferingResponse
  ): zio.aws.devicefarm.model.PurchaseOfferingResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-devicefarm_3-5.17.162.2-sources.jar: zio/aws/devicefarm/model/PurchaseOfferingResponse.scala <==
package zio.aws.devicefarm.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class PurchaseOfferingResponse(
    offeringTransaction: Optional[
      zio.aws.devicefarm.model.OfferingTransaction
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devicefarm.model.PurchaseOfferingResponse = {
    import PurchaseOfferingResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devicefarm.model.PurchaseOfferingResponse
      .builder()
      .optionallyWith(offeringTransaction.map(value => value.buildAwsValue()))(
        _.offeringTransaction
      )
      .build()
  }
  def asReadOnly: zio.aws.devicefarm.model.PurchaseOfferingResponse.ReadOnly =
    zio.aws.devicefarm.model.PurchaseOfferingResponse.wrap(buildAwsValue())
}
object PurchaseOfferingResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devicefarm.model.PurchaseOfferingResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devicefarm.model.PurchaseOfferingResponse =
      zio.aws.devicefarm.model.PurchaseOfferingResponse(
        offeringTransaction.map(value => value.asEditable)
      )
    def offeringTransaction
        : Optional[zio.aws.devicefarm.model.OfferingTransaction.ReadOnly]
    def getOfferingTransaction: ZIO[
      Any,
      AwsError,
      zio.aws.devicefarm.model.OfferingTransaction.ReadOnly
    ] = AwsError.unwrapOptionField("offeringTransaction", offeringTransaction)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devicefarm.model.PurchaseOfferingResponse
  ) extends zio.aws.devicefarm.model.PurchaseOfferingResponse.ReadOnly {
    override val offeringTransaction
        : Optional[zio.aws.devicefarm.model.OfferingTransaction.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.offeringTransaction())
        .map(value => zio.aws.devicefarm.model.OfferingTransaction.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devicefarm.model.PurchaseOfferingResponse
  ): zio.aws.devicefarm.model.PurchaseOfferingResponse.ReadOnly = new Wrapper(
    impl
  )
}
